==> angelsrefining_0.11.21.zip: angelsrefining_0.11.21/settings.lua <==
require "prototypes.angels-settings"

data:extend(
{
  {
    type = "string-setting",
		name = "angels-enable-auto-barreling",
		setting_type = "startup",
		default_value = "Disabled",
		allowed_values = {"Disabled","Enabled+Hidden","Enabled+Shown"},
    order = "aa"
  },
  {
    type = "bool-setting",
    name = "angels-enable-hide-void",
    setting_type = "startup",
    default_value = true,
    order = "ab"
  },
  {
    type = "bool-setting",
    name = "angels-tryptophobia-friendly-stiratite",
    setting_type = "startup",
    default_value = false,
    order = "ac"
  },
  {
    type = "bool-setting",
    name = "angels-hq-graphics",
    setting_type = "startup",
    default_value = true,
    order = "ad"
  },
  {
    type = "double-setting",
    name = "angels-marathon-buildingmulti",
    setting_type = "startup",
    default_value = 2,
    minimum_value = 1,
    maximum_value = 10,
    order = "ba"
  },
  {
    type = "double-setting",
    name = "angels-marathon-buildingtime",
    setting_type = "startup",
    default_value = 2,
    minimum_value = 1,
    maximum_value = 10,
    order = "bb"
  },
  {
    type = "double-setting",
    name = "angels-marathon-rawmulti",
    setting_type = "startup",
    default_value = 1,
    minimum_value = 1,
    maximum_value = 10,
    order = "bc"
  },
  {
    type = "double-setting",
    name = "angels-marathon-intermediatemulti",
    setting_type = "startup",
    default_value = 1,
    minimum_value = 1,
    maximum_value = 10,
    order = "bd"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore1",
    setting_type = "startup",
    default_value = true,
    order = "caa"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore2",
    setting_type = "startup",
    default_value = false,
    order = "cab"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore3",
    setting_type = "startup",
    default_value = true,
    order = "cac"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore4",
    setting_type = "startup",
    default_value = false,
    order = "cad"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore5",
    setting_type = "startup",
    default_value = true,
    order = "cae"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore6",
    setting_type = "startup",
    default_value = true,
    order = "caf"
  },
  {
    type = "double-setting",
    name = "angels-starting-resource-base",
    setting_type = "startup",
    default_value = 40000,
    minimum_value = 10000,
    maximum_value = 1000000,
    order = "cb"
  },
  {
    type = "int-setting",
    name = "angels-pavement-stack-size",
    setting_type = "startup",
    default_value = 200,
    minimum_value = 200,
    maximum_value = 1000,
    order = "d"
  },
}
)

==> angelsrefining_0.12.0.zip: angelsrefining_0.12.0/settings.lua <==
--INITIALIZE
angelsmods = angelsmods or {}
angelsmods.settings = angelsmods.settings or {}

--LOAD FUNCTIONS
require "prototypes.angels-settings"

--LOAD PROTOTYPES
data:extend(
{
  {
    type = "string-setting",
		name = "angels-enable-auto-barreling",
		setting_type = "startup",
		default_value = "Disabled",
		allowed_values = {"Disabled","Enabled+Hidden","Enabled+Shown"},
    order = "aa"
  },
  {
    type = "bool-setting",
    name = "angels-enable-hide-void",
    setting_type = "startup",
    default_value = true,
    order = "ab"
  },
  {
    type = "bool-setting",
    name = "angels-tryptophobia-friendly-stiratite",
    setting_type = "startup",
    default_value = false,
    order = "ac"
  },
  {
    type = "bool-setting",
    name = "angels-hq-graphics",
    setting_type = "startup",
    default_value = true,
    order = "ad"
  },
  {
    type = "double-setting",
    name = "angels-marathon-buildingmulti",
    setting_type = "startup",
    default_value = 2,
    minimum_value = 1,
    maximum_value = 10,
    order = "ba"
  },
  {
    type = "double-setting",
    name = "angels-marathon-buildingtime",
    setting_type = "startup",
    default_value = 2,
    minimum_value = 1,
    maximum_value = 10,
    order = "bb"
  },
  {
    type = "double-setting",
    name = "angels-marathon-rawmulti",
    setting_type = "startup",
    default_value = 1,
    minimum_value = 1,
    maximum_value = 10,
    order = "bc"
  },
  {
    type = "double-setting",
    name = "angels-marathon-intermediatemulti",
    setting_type = "startup",
    default_value = 1,
    minimum_value = 1,
    maximum_value = 10,
    order = "bd"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore1",
    setting_type = "startup",
    default_value = true,
    order = "caa"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore2",
    setting_type = "startup",
    default_value = false,
    order = "cab"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore3",
    setting_type = "startup",
    default_value = true,
    order = "cac"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore4",
    setting_type = "startup",
    default_value = false,
    order = "cad"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore5",
    setting_type = "startup",
    default_value = true,
    order = "cae"
  },
  {
    type = "bool-setting",
    name = "angels-starting-resource-ore6",
    setting_type = "startup",
    default_value = true,
    order = "caf"
  },
  {
    type = "double-setting",
    name = "angels-starting-resource-base",
    setting_type = "startup",
    default_value = 40000,
    minimum_value = 10000,
    maximum_value = 1000000,
    order = "cb"
  },
  {
    type = "int-setting",
    name = "angels-pavement-stack-size",
    setting_type = "startup",
    default_value = 200,
    minimum_value = 200,
    maximum_value = 1000,
    order = "d"
  }
}
)
